@@ -1,9 +1,7 @@
-from RobotAxeLibrary import RobotAxeLibrary
+from .RobotAxeLibrary import RobotAxeLibrary
 
 def main():
     lib = RobotAxeLibrary()
-    lib.helloA11y()
-    return lib
 
 if __name__ == '__main__':
     main()
\ No newline at end of file
